@@ -29,17 +29,17 @@ Geom <- proto(TopLevel, expr={
     ))
   }
   
-  adjust_scales_data <- function(., scales, data) data
-  
   new <- function(., mapping=NULL, data=NULL, stat=NULL, position=NULL, ...){
     do.call("layer", list(mapping=mapping, data=data, stat=stat, geom=., position=position, ...))
   }
   
   pprint <- function(., newline=TRUE) {
-    cat("geom_", .$objname, ": ", clist(.$parameters()), sep="")
+    cat("geom_", .$objname, ": ", sep="") #  , clist(.$parameters())
     if (newline) cat("\n")
   }
   
+  reparameterise <- function(., data, params) data
+  
   # Html documentation ----------------------------------
 
     
