@@ -1,5 +1,6 @@
-GeomSmooth <- proto(GeomInterval, {
+GeomSmooth <- proto(Geom, {
   draw <- function(., data, scales, coordinates, ...) {
+    data$fill <- alpha(data$fill, data$alpha)
     gList(
       tryNULL(GeomRibbon$draw(transform(data, colour=NA), scales, coordinates)),
       GeomPath$draw(rename(data, c(middle = "y")), scales, coordinates)
@@ -15,16 +16,17 @@ GeomSmooth <- proto(GeomInterval, {
     ))
   }
   
-  adjust_scales_data <- function(., scales, data) data
   guide_geom <- function(.) "smooth"
   
   default_stat <- function(.) StatSmooth
   required_aes <- c("x", "y")
-  default_aes <- function(.) aes(colour="grey50", fill=alpha("black", 0.2), size=0.5, linetype=1, weight=1)
+  default_aes <- function(.) aes(colour="#3366FF", fill="grey60", size=0.5, linetype=1, weight=1, alpha=0.4)
 
 
   draw_legend <- function(., data, ...) {
     data <- aesdefaults(data, .$default_aes(), list(...))
+    data$fill <- alpha(data$fill, data$alpha)
+    
     gTree(children = gList(
       GeomTile$draw_legend(data, ...),
       GeomPath$draw_legend(data, ...)
