@@ -1,3 +1,41 @@
+# Legends
+# Create and arrange legends for all scales.
+# 
+# This function gathers together all of the legends produced by 
+# the scales that make up the plot and organises them into a 
+# \\code{\\link[grid]{frameGrob}}.  
+# 
+# If there are no legends to create, this function will return \\code{NULL}
+# 
+# @arguments scales object
+# @arguments direction of scales, vertical by default
+# @keyword hplot 
+# @value frameGrob, or NULL if no legends
+# @keyword internal
+guide_legends_box <- function(scales, scale_usage, horizontal = FALSE, theme) {
+  legs <- guide_legends(scales, scale_usage, theme=theme)
+  
+  n <- length(legs)
+  if (n == 0) return(nullGrob())
+  
+  if (!horizontal) {
+    width <-   do.call("max", lapply(legs, widthDetails))
+    heights <- do.call("unit.c", lapply(legs, function(x) heightDetails(x) * 1.1))
+    fg <- frameGrob(grid.layout(nrow=n, 1, widths=width, heights=heights, just="centre"), name="legends")
+    for(i in 1:n) {
+      fg <- placeGrob(fg, legs[[i]], row=i)
+    }
+  } else {
+    height <- do.call("sum", lapply(legs, heightDetails))
+    widths <- do.call("unit.c", lapply(legs, function(x) widthDetails(x) * 1.1))
+    fg <- frameGrob(grid.layout(ncol=n, 1, widths=widths, heights=height, just="centre"), name="legends")
+    for(i in 1:n) {
+      fg <- placeGrob(fg, legs[[i]], col=i)
+    }
+  }
+  fg
+}
+
 # Build all legend grob
 # Build legends, merging where possible
 # 
@@ -5,12 +43,14 @@
 # @argument list description usage of aesthetics in geoms
 # @keyword internal
 # @value A list of grobs
-gglegends <- function(legends, usage) {
-  # Need to collapse legends describing same values into single data.frame
-  # - first group by name
+guide_legends <- function(scales, usage, theme) {
+  legends <- compact(lapply(scales$get_trained_scales(), function(sc) sc$legend_desc()))
+  
   if (length(legends) == 0) 
     return()
   
+  # Need to collapse legends describing same values into single data.frame
+  # - first group by name
   legend_names <- unname(unlist(lapply(legends, "[", "name")))
   name_strings <- sapply(legend_names, deparse)
   names(legend_names) <- name_strings
@@ -22,7 +62,7 @@ gglegends <- function(legends, usage) {
   keys_merged <- lapply(variables, merge_legends)
   legends_merged <- mapply(function(name, keys) list(name = legend_names[name], display=keys), names(keys_merged), keys_merged, SIMPLIFY = FALSE, USE.NAMES = FALSE)  
   
-  lapply(legends_merged, gglegend, usage=usage)
+  lapply(legends_merged, guide_legend, usage=usage, theme=theme)
 }
 
 # Merge legends
@@ -49,21 +89,25 @@ merge_legends <- function(legends) {
 # @argument list description usage of aesthetics in geoms
 # @value A grid grob
 # @keyword internal
-gglegend <- function(legend, usage=usage) {
+guide_legend <- function(legend, usage=usage, theme) {
   display <- legend$display
+  display <- display[nrow(display):1, ]
 
   aesthetics <- setdiff(names(legend$display), "label")
   
   legend_f <- function(x) {
     geom <- Geom$find(x)
-    used <- names(Filter(function(geom) any(geom == x), usage))
-    function(data) geom$draw_legend(data[used])
+    used <- names(Filter(function(geom) any(geom == x), usage$aesthetics))
+    params <- usage$parameters[[x]]
+    
+    function(data) geom$draw_legend(defaults(params, data[used]))
   }
-  grobs <- lapply(unique(unlist(usage[aesthetics])), legend_f)
+  grobs <- lapply(unique(unlist(usage$aesthetics[aesthetics])), legend_f)
 
-  title <- ggname("title", textGrob(legend$name[[1]], x = 0, y = 0.5, just = c("left", "centre"), 
-    gp=gpar(fontface="bold")
-  ))
+  title <- theme_render(
+    theme, "legend.title",
+    legend$name[[1]], x = 0, y = 0.5
+  )
   
   nkeys <- nrow(display)
   hgap <- vgap <- unit(0.3, "lines")
@@ -72,7 +116,7 @@ gglegend <- function(legend, usage=usage) {
   label.heights <- do.call("unit.c", lapply(display$label, function(x) stringHeight(as.expression(x))))
   label.widths  <- do.call("unit.c", lapply(display$label, function(x) stringWidth(as.expression(x))))
 
-  grobwidth <- if ("point" %in% usage[aesthetics] && !is.null(display$size)) {
+  grobwidth <- if ("point" %in% usage$aesthetics[aesthetics] && !is.null(display$size)) {
     unit(max(display$size) / 2, "mm")
   } else {
     unit(0, "mm")
@@ -97,20 +141,49 @@ gglegend <- function(legend, usage=usage) {
   # Layout the legend table
   legend.layout <- grid.layout(nkeys + 1, 4, widths = widths, heights = heights, just=c("left","top"))
   fg <- ggname("legend", frameGrob(layout = legend.layout))
-  #fg <- placeGrob(fg, rectGrob(gp=gpar(fill="NA", col="NA", name="legend-background")))
+  fg <- placeGrob(fg, theme_render(theme, "legend.background"))
 
   numeric_labels <- all(sapply(display$label, is.language)) || suppressWarnings(all(!is.na(sapply(display$label, "as.numeric"))))
-  valign <- if(numeric_labels) "right" else "left"
-  vpos   <- if(numeric_labels) 1 else 0
+  hpos <- numeric_labels * 1
 
-  fg <- placeGrob(fg, title, col=1:2, row=1)
+  fg <- placeGrob(fg, title, col=1:3, row=1)
   for (i in 1:nkeys) {
     df <- as.list(display[i,, drop=FALSE])
+    
+    fg <- placeGrob(fg, theme_render(theme, "legend.key"), col = 1, row = i+1)      
     for(grob in grobs) {
       fg <- placeGrob(fg, ggname("key", grob(df)), col = 1, row = i+1)      
     }
-    fg <- placeGrob(fg, ggname("label", textGrob(display$label[[i]], x = vpos, y = 0.5, just = c(valign, "centre"))), col = 3, row = i+1)
+    label <- theme_render(
+      theme, "legend.text", 
+      display$label[[i]], hjust = hpos,
+      x = hpos, y = 0.5
+    )
+    fg <- placeGrob(fg, label, col = 3, row = i+1)
   }
 
   fg
-}
\ No newline at end of file
+}
+
+# Compute usage of scales
+# Builds a list of aesthetics and the geoms that they are used by.
+# 
+# Used for drawing legends.
+# 
+# @arguments ggplot object
+# @keyword internal
+scale_usage <- function(plot) {
+  aesthetics <- lapply(plot$layers, 
+    function(p) p$aesthetics_used(plot$defaults)
+  )
+  params <- lapply(plot$layers, function(p) p$geom_params)
+
+  geom_names <- sapply(plot$layers, function(p) p$geom$guide_geom())
+  names(aesthetics) <- geom_names
+  names(params) <- geom_names
+  
+  list(
+    aesthetics = lapply(invert(aesthetics), unique), 
+    parameters = params
+  )
+}
