@@ -1,20 +1,28 @@
+# Domain: raw, transformed, user (limits)
+# Range:  raw, transformed
+
+
 Scale <- proto(TopLevel, expr={
   .input <- ""
   .output <- ""
-  .reverse <- FALSE
   common <- NULL  
   legend <- TRUE
+  limits <- NULL
+  doc <- TRUE
   
   class <- function(.) "scale"
   
   new <- function(., name="Unknown") {
     .$proto(name=name)
   }
-  discrete <- function(.) FALSE
   
   clone <- function(.) {
     as.proto(.$as.list(all.names=TRUE), parent=.) 
   }
+  
+  trained <- function(.) {
+    !is.null(.$input_set())
+  }
 
   find <- function(., output, only.documented = FALSE) {
     scales <- Scales$find_all()
@@ -24,27 +32,33 @@ Scale <- proto(TopLevel, expr={
     unique(scales[select])
   }
 
+  # Input --------------------------------------------------------------------
+  
+  breaks <- NULL
+
   input <- function(.) .$.input
+  input_set <- function(.) {
+    nulldefault(.$limits, .$.domain)
+  }
+  
+  # Output -------------------------------------------------------------------
+  
   output <- function(.) .$.output
-  domain <- function(.) .$.domain
+  output_breaks <- function(.) .$map(.$input_breaks())
+  output_expand <- function(.) {
+    expand_range(.$output_set(), .$.expand[1], .$.expand[2])    
+  }
   
   # Train scale from a data frame
   train_df <- function(., df) {
-    .$train(df[[.$input()]])
-  }
-
-  transform_df <- function(., df) {
-    input <- .$input()
-    output <- .$output()
-    transform <- function(var) .$stransform(df[, var])
+    if (!is.null(.$limits)) return()
     
-    if (length(input) == 1 && input == "y") {
-      input <- output <- intersect(c("y","min", "max"), names(df))
+    input <- .$input()
+    if (length(input) == 1 && input %in% c("x", "y")) {
+      matches <- grep(paste("^", input, sep =""), names(df))
+      input <- names(df)[matches]
     }
-    df <- do.call("data.frame", lapply(input, transform))
-    if (ncol(df) == 0) return(NULL)
-    names(df) <- output      
-    df
+    l_ply(input, function(var) .$train(df[[var]]))
   }
 
   # Map values from a data.frame.   Returns data.frame
@@ -60,13 +74,33 @@ Scale <- proto(TopLevel, expr={
     if (ncol(output) > 0) names(output) <- .$output()
     output
   }
+
+  # Guides
+  # ---------------------------------------------
+  legend_desc <- function(.) {
+    if (identical(., Scale) || !.$legend) return()
+   
+    breaks <- .$output_breaks()
+    labels <- .$labels()
+    
+    if (is.null(breaks) || is.null(labels)) return()
+    
+    df <- data.frame(breaks, stringsAsFactors = FALSE)
+    names(df) <- .$output()
+    df$label <- labels
+    list(
+      name = nulldefault(.$name, ""),
+      aesthetic = .$output(),
+      display = df
+    )
+  }
   
   pprint <- function(., newline=TRUE) {
     clist <- function(x) paste(x, collapse=",")
     
     cat("scale_", .$objname, ": ", clist(.$input()),   " -> ", clist(.$output()), sep="")
-    if (!is.null(.$domain())) {
-      cat(" (", clist(.$domain()), " -> ", clist(.$frange()), ")", sep="")
+    if (!is.null(.$input_set())) {
+      cat(" (", clist(.$input_set()), " -> ", clist(.$output_set()), ")", sep="")
     }
     if (newline) cat("\n") 
   }
@@ -82,23 +116,8 @@ Scale <- proto(TopLevel, expr={
     ps(.$class(), .$common, .$objname, sep="_", collapse=NULL)
   }
   
-  # Guides
-  # ---------------------------------------------
-  legend_desc <- function(.) {
-    if (identical(., Scale) || !.$legend) return()
-    
-    breaks <- .$rbreaks()
-    labels <- .$labels()
-    if (is.null(breaks) || is.null(labels)) return()
-    
-    df <- data.frame(breaks, stringsAsFactors = FALSE)
-    names(df) <- .$output()
-    df$label <- labels
-    list(
-      name = nulldefault(.$name, ""),
-      aesthetic = .$output(),
-      display = df
-    )
+  my_full_name <- function(.) {
+    ps(.$class(), .$input(), .$objname, sep="_", collapse=NULL)
   }
   
   parameters <- function(.) {
