@@ -1,82 +1,91 @@
-ScaleContinuous <- proto(Scale, {
+ScaleContinuous <- proto(Scale, funEnvir = globalenv(), {  
   .domain <- c()
   .range <- c()
   .expand <- c(0.05, 0)
-  limits <- c(NA, NA)
   .labels <- NULL
+  discrete <- function(.) FALSE
+  
+  tr_default <- "identity"
 
-  new <- function(., name=NULL, limits=c(NA,NA), breaks=NULL, labels=NULL, variable, trans="identity", expand=c(0.05, 0)) {
+  new <- function(., name=NULL, limits=NULL, breaks=NULL, labels=NULL, variable, trans = NULL, expand=c(0.05, 0), minor_breaks = NULL, ...) {
     if (is.null(breaks) && !is.null(labels)) stop("Labels can only be specified in conjunction with breaks")
     
-    .$proto(name=name, .input=variable, .output=variable, limits=limits, .breaks = breaks, .labels = labels, .expand=expand)
+    if (is.null(trans))      trans <- .$tr_default
+    if (is.character(trans)) trans <- Trans$find(trans)
+    
+    # Transform limits and breaks
+    limits <- trans$transform(limits)
+    breaks <- trans$transform(breaks)
+    
+    .$proto(name=name, .input=variable, .output=variable, limits=limits, breaks = breaks, .labels = labels, .expand=expand, .tr = trans, minor_breaks = minor_breaks, ...)
   }
 
-  domain <- function(.) {
-    c(
-      if(is.na(.$limits[1])) .$.domain[1] else .$.tr$transform(.$limits[1]),
-      if(is.na(.$limits[2])) .$.domain[2] else .$.tr$transform(.$limits[2])
-    )
-  }
   
-  stransform <- function(., values) {
-    .$.tr$transform(values)
-  }
-  
-  map <- function(., values) {
-    rescale(values, .$frange(), .$domain())
+  # Transform each 
+  transform_df <- function(., df) {
+    input <- .$input()
+    output <- .$output()
+    
+    if (length(input) == 1 && input %in% c("x", "y")) {
+      matches <- grep(paste("^", input, sep =""), names(df))
+      input <- output <- names(df)[matches]
+    }
+    input <- intersect(input, names(df))
+
+    df <- colwise(.$.tr$transform)(df[input])
+    if (ncol(df) == 0) return(NULL)
+    names(df) <- output      
+    df
   }
   
   train <- function(., x) {
     if (is.null(x)) return()
-    if (!is.numeric(x)) 
-      warning("Non-numeric variable supplied to continuous scale ", .$name, ".", call.=FALSE)
+    if (!is.numeric(x)) {
+      stop(
+        "Non-continuous variable supplied to ", .$my_full_name(), ".",
+        call.=FALSE
+      )
+    }
     if (all(is.na(x))) return()
-      
-    .$.domain <- range(range(x, na.rm=TRUE, finite=TRUE), .$.domain, na.rm=TRUE, finite=TRUE)
-  }
-
-  # Scale range
-  frange <- function(.) {
-    nulldefault(.$.range, .$domain())
-  }
-  
-  # Breaks are regular on the transformed scale
-  .breaks <- NULL
-  breaks <- function(.) {
-    if (!is.null(.$.breaks)) return(.$.tr$transform(.$.breaks))
-    grid.pretty(.$domain())
-  }
-
-  rbreaks <- function(.) {
-    if (!is.null(.$.breaks)) return(.$.breaks)
-    .$map(grid.pretty(.$domain()))
-  }
-
-  .minor_breaks <- 2
-  # Minor breaks are regular on the original scale
-  # and need to cover entire range of plot
-  minor_breaks <- function(., n = .$.minor_breaks, b = .$breaks(), r = .$frange()) {
-    if (length(b) == 1) return(b)
     
-    bd <- diff(b)[1]
-    if (min(r) < min(b)) b <- c(b[1] - bd, b)
-    if (max(r) > max(b)) b <- c(b, b[length(b)] + bd)
-    unique(unlist(mapply(.$.tr$seq, b[-length(b)], b[-1], length=n+1, SIMPLIFY=F)))
+    .$.domain <- range(x, .$.domain, na.rm=TRUE, finite=TRUE)
+  }
+    
+  # By default, a continuous scale does no transformation in the mapping stage
+  # See scale_size for an exception
+  map <- function(., values) {
+    as.numeric(ifelse(values %inside% .$output_set(), values, NA))
+  }
+
+  # By default, the range of a continuous scale is the same as its
+  # (transformed) domain
+  output_set <- function(.) .$input_set()
+  
+  # By default, breaks are regularly spaced along the (transformed) domain
+  input_breaks <- function(.) {
+    nulldefault(.$breaks, .$.tr$input_breaks(.$input_set()))
+  }
+  input_breaks_n <- function(.) .$input_breaks()
+
+
+  minor_breaks <- NULL
+  output_breaks <- function(., n = 2, b = .$input_breaks(), r = .$output_set()) {
+    nulldefault(.$minor_breaks, .$.tr$output_breaks(n, b, r))
   }
   
   labels <- function(.) {
     if (!is.null(.$.labels)) return(.$.labels)
-    b <- .$breaks()
+    b <- .$input_breaks()
 
     l <- .$.tr$label(b)
     numeric <- sapply(l, is.numeric)
-    l[numeric] <- format(unlist(l[numeric]))
+    l[numeric] <- format(unlist(l[numeric]), trim = TRUE)
     l
   }
   
   test <- function(.) {
-    m <- .$minor_breaks(10)
-    b <- .$breaks()
+    m <- .$output_breaks(10)
+    b <- .$input_breaks()
     
     plot(x=0,y=0,xlim=range(c(b,m)), ylim=c(1,5), type="n", axes=F,xlab="", ylab="")
     for(i in 1:(length(b))) axis(1, b[[i]], as.expression(.$labels()[[i]]))
@@ -86,13 +95,13 @@ ScaleContinuous <- proto(Scale, {
   }
   
   objname <- "continuous"
-  common <- c("x", "y", "z", "xend", "yend")
+  common <- c("x", "y", "z")
   desc <- "Continuous position scale"
   seealso <- list(
     "scale_discrete" = "Discrete position scales"
   )
   examples <- function(.) {
-    (m <- qplot(rating, votes, data=movies))
+    (m <- qplot(rating, votes, data=subset(movies, votes > 1000)))
     
     # Manipulating the default position scales lets you:
 
@@ -101,8 +110,8 @@ ScaleContinuous <- proto(Scale, {
     m + scale_y_continuous(expression(votes^alpha))
     
     #  * modify the axis limits
-    m + scale_y_continuous(limits=c(NA, 5000))
-    m + scale_y_continuous(limits=c(1000, NA))
+    m + scale_y_continuous(limits=c(0, 5000))
+    m + scale_y_continuous(limits=c(1000, 10000))
     m + scale_x_continuous(limits=c(7, 8))
 
     #  * choose where the ticks appear
@@ -110,20 +119,21 @@ ScaleContinuous <- proto(Scale, {
     m + scale_x_continuous(breaks=c(1,3,7,9))
 
     #  * manually label the ticks
-    m + scale_x_continuous(breaks=c(1,5,10), labels=c("one", "five", "ten"))
-    m + scale_x_continuous(breaks=c(1,5,10), labels=c("horrible", "ok", "awesome"))
-    m + scale_x_continuous(breaks=c(1,5,10), labels=expression(Alpha, Beta, Omega))
+    m + scale_x_continuous(breaks=c(2,5,8), labels=c("two", "five", "eight"))
+    m + scale_x_continuous(breaks=c(2,5,8), labels=c("horrible", "ok", "awesome"))
+    m + scale_x_continuous(breaks=c(2,5,8), labels=expression(Alpha, Beta, Omega))
     
     # There are also a wide range of transformations you can use:
     m + scale_y_log10()
     m + scale_y_log()
     m + scale_y_log2()
     m + scale_y_sqrt()
+    m + scale_y_reverse()
     # see ?transformer for a full list
     
     # qplot allows you to do some of this with a little less typing:
     #   * axis limits
-    qplot(rating, votes, data=movies, xlim=c(5,10), ylim=c(50000, NA))
+    qplot(rating, votes, data=movies, ylim=c(1e4, 5e4))
     #   * axis labels
     qplot(rating, votes, data=movies, xlab="My x axis", ylab="My y axis")
     #   * log scaling
