@@ -2,20 +2,20 @@ ScaleGrey <- proto(ScaleColour, expr={
   doc <- TRUE
   common <- c("colour", "fill")
 
-  new <- function(., name=NULL, variable, start = 0.2, end = 0.8, labels=NULL) {
-    .$proto(name=name, .input=variable, .output=variable, start=start, end=end, .labels = labels)
+  new <- function(., name=NULL, variable, start = 0.2, end = 0.8, limits=NULL, breaks = NULL, labels=NULL) {
+    .$proto(name=name, .input=variable, .output=variable, start=start, end=end, limits = limits, breaks = breaks, .labels = labels)
   }
 
-  breaks <- function(.) {
-    grey.colors(length(.$domain()), start = .$start, end = .$end)
+  output_set <- function(.) {
+    grey.colors(length(.$input_breaks()), start = .$start, end = .$end)
   }
 
   max_levels <- function(.) Inf
 
-  # Documetation -----------------------------------------------
+  # Documentation -----------------------------------------------
 
   objname <- "grey"
-  desc <- "Grey colour scale"
+  desc <- "Sequential grey colour scale"
   details <- "<p>Based on ?gray.colors</p>"
   
   desc_params <- list(
