@@ -1,8 +1,9 @@
 
 ScaleIdentity <- proto(ScaleDiscrete, {  
+  doc <- TRUE
   common <- c("colour","fill","size","shape","linetype")
   new <- function(., name=NULL, breaks=NULL, labels=NULL, variable="x") {
-    .$proto(name=name, .breaks=breaks, .labels=labels, .input=variable, .output=variable)
+    .$proto(name=name, breaks=breaks, .labels=labels, .input=variable, .output=variable)
   }
 
   guides.manual <- function(scale, ...) {
@@ -11,24 +12,24 @@ ScaleIdentity <- proto(ScaleDiscrete, {
   }
   
   train <- function(., data) {
-    .$.breaks <- union(.$.breaks, unique(data))
+    .$breaks <- union(.$breaks, unique(data))
   }
   map_df <- function(., data) {
     if (!all(.$input() %in% names(data))) return(data.frame())
     data[, .$input(), drop=FALSE]
   }
-  breaks <- function(.) .$.breaks
+  output_breaks <- function(.) .$breaks
   labels <- function(.) .$.labels
 
-  guide_legend <- function(.) {
+  guide_legend <- function(., background="grey90") {
     if (is.null(.$.labels)) return()
-    .super$guide_legend(.)
+    .super$guide_legend(., background=background)
   }
   
-  # Documetation -----------------------------------------------
+  # Documentation -----------------------------------------------
 
   objname <- "identity"
-  desc <- "Don't remap values, use directly"
+  desc <- "Use values without scaling"
   icon <- function(.) textGrob("f(x) = x", gp=gpar(cex=1.2))
   
   examples <- function(.) {
@@ -37,9 +38,8 @@ ScaleIdentity <- proto(ScaleDiscrete, {
     qplot(1:4, 1:4, fill=colour, geom="tile") + scale_fill_identity()
     
     # To get a legend, you also need to supply the labels to
-    # be used on the legend, and the grob to draw them:
-    # grob_tile, grob_line, or grob_point
-    qplot(1:4, 1:4, fill=colour, geom="tile") + scale_fill_identity(labels=letters[1:4], guide="tile", name="trt")
+    # be used on the legend
+    qplot(1:4, 1:4, fill=colour, geom="tile") + scale_fill_identity(labels=letters[1:4], name="trt")
     
     # cyl scaled to appropriate size
     qplot(mpg, wt, data=mtcars, size = cyl)
