@@ -1,11 +1,14 @@
 ScaleLinetype <- proto(ScaleDiscrete, expr={
+  doc <- TRUE
   common <- NULL
   .input <- .output <- "linetype"
 
-  frange <- function(.) (1:4)[1:length(.$domain())]
+  output_set <- function(.) c("22", "44", "13", "1343", "73", "2262", "12223242", "F282", "F4448444", "224282F2", "F1")[seq_along(.$input_set())]
   max_levels <- function(.) 4
   
-  # Documetation -----------------------------------------------
+  detail <- "<p>Default line types supplied by Richard Pearson, University of Manchester.</p>"
+  
+  # Documentation -----------------------------------------------
 
   objname <- "linetype"
   desc <- "Scale for line patterns"
