@@ -1,7 +1,7 @@
 StatFunction <- proto(Stat, {
   
   calculate <- function(., data, scales, fun, n=101, args = list(), ...) {
-    range <- scales$get_scales("x")$frange()
+    range <- scales$get_scales("x")$output_set()
     xseq <- seq(range[1], range[2], length=n)
     
     data.frame(
@@ -18,6 +18,11 @@ StatFunction <- proto(Stat, {
     n = "number of points to interpolate along",
     args = "list of additional arguments to pass to fun"
   )
+  
+  desc_outputs <- list(
+    x = "x's along a grid",
+    y = "value of function evaluated at corresponding x"
+  )
 
   default_geom <- function(.) GeomPath
   
