@@ -10,14 +10,23 @@ summary.ggplot <- function(object, ...) {
     }, object$defaults, names(object$defaults)), collapse=", ")
   }
   
-  cat("Title:   ", object$title, "\n", sep="")
-  cat("Labels:  x=", object$xlabel, ", y=", object$ylabel, "\n", sep="")
+  cat("Title:    ", object$title, "\n", sep="")
   cat("-----------------------------------\n")
-  cat("Data:    ", paste(names(object$data), collapse=", "), " [", nrow(object$data), "x", ncol(object$data), "] ", "\n", sep="")
-  cat("Mapping: ", defaults(), "\n", sep="")
-  object$scales$pprint()
+  if (!is.null(object$data)) {
+    cat("Data:     ", paste(names(object$data), collapse=", "), " [", nrow(object$data), "x", ncol(object$data), "] ", "\n", sep="")    
+  }
+  if (length(object$defaults) > 0) {
+    cat("Mapping:  ", defaults(), "\n", sep="")    
+  }
+  if (object$scales$n() > 0) {
+    object$scales$pprint()    
+  }
+  
+  cat("Faceting: ")
   object$facet$pprint()
-  cat("-----------------------------------\n")
+
+  if (length(object$layers) > 0)
+    cat("-----------------------------------\n")
   invisible(lapply(object$layers, function(x) {print(x); cat("\n")}))
 
 } 
\ No newline at end of file
